==> neoproxy-0.2.3.tgz: package/example.js <==
var Proxy = require('./index');
var defaults = Proxy.defaults;
var proxy = Proxy();

//
var INTERVAL = 1000; // 1s
var LIMIT = 1024*10; // 10kB
proxy.use(function(req){return !req.is_resolved},
	function(req){console.log(req.url)})
proxy.use({
	// to store timestamp, data length for calculations.
	obj: {},
	queue: [],
	process: function(){
		var self = this;
		var queue = self.queue;
		var obj = self.obj;
		while(Array.isArray(queue[0]) && queue[0][0] === null){
			var packet = queue.shift();;
			var chunk = packet[0];
			var push = packet[1];
			push(chunk);
		}
		if(queue.length){
			var date = Date.now();
			var count = 0;
			for (var i in obj){
				if(date-i>INTERVAL){
					delete obj[i];
				}
				else{
					count += obj[i];
				}
			}
			if(count<LIMIT){
				var packet = queue.shift();;
				var chunk = packet[0];
				var push = packet[1];
				push(chunk);
				obj[date] = chunk.length;
			}
			setTimeout(self.process.bind(self),0);
		}
	},
	condition: function(req,res){
		return req.is_resolved;
	},
	middleware: function(req,res,push){
		console.log(req.url)
		var self = this;
		return function(x){
			self.queue.push([x,push]);
			self.process();
		}
	}
})
// proxy.use({
// 	condition: function(req,res){
// 		return req.headers.accept && !~req.headers.accept.indexOf('html')
// 	},
// 	middleware: function(req,res,push){
// 		console.log(req.url)
// 		var a = Math.random();
// 		var last = Date.now();
		
// 		return function(x){
// 			var a = function(){
// 				push(x)
// 			};
// 			last += 2000;
// 			var d = Date.now()
// 			last = last>d?last:d
// 			var as = last-d;
// 			setTimeout(a,as)
// 		}
// 	}
// })

// proxy.use(defaults.concat)
// proxy.use(function(req){
// 	return !req.is_resolved
// },
// function(req,res,push){
// 	req.headers['user-agent'] = 'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:38.0) Gecko/20100101 Firefox/38.0';
// 	return function(x){
// 		push(x)
// 	}
// })
// proxy.use(function(req){
// 	return req.is_resolved
// },
// function(req,res,push){
// 	console.log(req.url,res.response.headers)
// 	var a = 0;
// 	return function(x){
// 		a+=(x && x.length) || 0;
// 		console.log(req.url, a)
// 		push(x)
// 	}
// })
// proxy.use({
// 	condition: function(req,res){
// 		return req.method.toLowerCase() == 'post' && req.is_resolved == false;
// 	},
// 	middleware: function(req,res,push){
// 		console.log(req.body.toString())
// 		return push;
// 	}
// })
// proxy.use({
// 	condition: function(req,res){
// 		return !req.is_resolved
// 	},
// 	middleware: function(req,res,push){
// 		console.log('aborted')
// 		req.abort()
		
// 	}
// })
// proxy.use({
// 	condition: function(req,res){
// 		return !req.is_resolved
// 	},
// 	middleware: function(req,res,push){
// 		console.log(req.url)
// 	}
// })
// proxy.use({
// 	condition: function(req,res){
// 		return req.is_resolved && res.response.statusCode == 301
// 			&& res.response.headers.location.indexOf('https://')==0
// 	},
// 	middleware: function(req,res,push){
// 		req.url = res.response.headers.location;
// 		console.log('https:::::',req.url)
// 		req.retry = true;
// 		return push;
// 	}
// });
var server = proxy.listen(8000, function () {
	var host = server.address().address;
	var port = server.address().port;
	console.log('proxy server listening at http://%s:%s', host, port);
})

==> neoproxy-0.2.8.tgz: package/example.js <==
var Proxy = require('./index');
var defaults = Proxy.defaults;
var proxy = Proxy();

//
// var INTERVAL = 1000; // 1s
// var LIMIT = 1024*10; // 10kB
// proxy.use(function(req){return !req.is_resolved},
// 	function(req){console.log(req.url)})
// proxy.use({
// 	// to store timestamp, data length for calculations.
// 	obj: {},
// 	queue: [],
// 	process: function(){
// 		var self = this;
// 		var queue = self.queue;
// 		var obj = self.obj;
// 		while(Array.isArray(queue[0]) && queue[0][0] === null){
// 			var packet = queue.shift();;
// 			var chunk = packet[0];
// 			var push = packet[1];
// 			push(chunk);
// 		}
// 		if(queue.length){
// 			var date = Date.now();
// 			var count = 0;
// 			for (var i in obj){
// 				if(date-i>INTERVAL){
// 					delete obj[i];
// 				}
// 				else{
// 					count += obj[i];
// 				}
// 			}
// 			if(count<LIMIT){
// 				var packet = queue.shift();;
// 				var chunk = packet[0];
// 				var push = packet[1];
// 				push(chunk);
// 				obj[date] = chunk.length;
// 			}
// 			setTimeout(self.process.bind(self),0);
// 		}
// 	},
// 	condition: function(req,res){
// 		return req.is_resolved;
// 	},
// 	middleware: function(req,res,push){
// 		console.log(req.url)
// 		var self = this;
// 		return function(x){
// 			self.queue.push([x,push]);
// 			self.process();
// 		}
// 	}
// })
// proxy.use({
// 	condition: function(req,res){
// 		return req.headers.accept && !~req.headers.accept.indexOf('html')
// 	},
// 	middleware: function(req,res,push){
// 		console.log(req.url)
// 		var a = Math.random();
// 		var last = Date.now();
		
// 		return function(x){
// 			var a = function(){
// 				push(x)
// 			};
// 			last += 2000;
// 			var d = Date.now()
// 			last = last>d?last:d
// 			var as = last-d;
// 			setTimeout(a,as)
// 		}
// 	}
// })

// proxy.use(defaults.concat)
// proxy.use(function(req){
// 	return !req.is_resolved
// },
// function(req,res,push){
// 	req.headers['user-agent'] = 'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:38.0) Gecko/20100101 Firefox/38.0';
// 	return function(x){
// 		push(x)
// 	}
// })
// proxy.use(function(req){
// 	return req.is_resolved
// },
// function(req,res,push){
// 	console.log(req.url,res.response.headers)
// 	var a = 0;
// 	return function(x){
// 		a+=(x && x.length) || 0;
// 		console.log(req.url, a)
// 		push(x)
// 	}
// })
proxy.use({
	condition: function(req,res){
		return true;
		// return req.method.toLowerCase() == 'post' && req.is_resolved == false;
	},
	middleware: function(req,res,push){
		console.log(req.headers)
		return push;
	}
})
// proxy.use({
// 	condition: function(req,res){
// 		return !req.is_resolved
// 	},
// 	middleware: function(req,res,push){
// 		console.log('aborted')
// 		req.abort()
		
// 	}
// })
// proxy.use({
// 	condition: function(req,res){
// 		return !req.is_resolved
// 	},
// 	middleware: function(req,res,push){
// 		console.log(req.url)
// 	}
// })
// proxy.use({
// 	condition: function(req,res){
// 		return req.is_resolved && res.response.statusCode == 301
// 			&& res.response.headers.location.indexOf('https://')==0
// 	},
// 	middleware: function(req,res,push){
// 		req.url = res.response.headers.location;
// 		console.log('https:::::',req.url)
// 		req.retry = true;
// 		return push;
// 	}
// });
var server = proxy.listen(8000, function () {
	var host = server.address().address;
	var port = server.address().port;
	console.log('proxy server listening at http://%s:%s', host, port);
})
